/*******************************************************************************************************************
Replication syntax for: "The Impact of EU Institutional Advertising on Public Support for European Integration"
By: Enrique Hernández and Roberto Pannico
Last updated: May 26, 2020
Original analyses conducted with Stata 16SE
Additional ado-files required to run the do-file: estout, blindschemes, coefplot, mediation, frmttable, addplot
The whole syntax should be run at once.  
*********************************************************************************************************************/

************************************************
* Preamble
************************************************
* Directory structure
capture cd "" // Introduce here directory/folder where replication files were unzipped 

global original "00_original_data/"
global working "01_working_data/"
global do "02_do_files/"
global output "03_output/"
global aux "04_aux/"

* Required ado-files
ssc install blindschemes, replace 
ssc install estout, replace 
ssc install coefplot, replace 
ssc install mediation, replace
net install sg97_5, replace from(http://www.stata-journal.com/software/sj12-4) 
ssc install addplot, replace
ssc install moremata, replace
mata mata mlib index

* Setting plots color scheme 
set scheme plottigblind

* Loading POLAT survey dataset 
use ${original}POLAT_W10.dta, clear

* Labelling labels 
numlabel _all, add

* Log
log using ${output}replication_log.smcl, replace

************************************************
* Data management
************************************************

* Treatment variables 
	* Full treatment variable 
gen treatment = GRUPO_EXPERIMENTO_2

label def tr 1"Control" 2"Costs treatment" 3"Policy benefits treatment" 
label val treatment tr

	* Dichotomized treatment variables 
recode GRUPO_EXPERIMENTO_2 (1 = 0) (2 = 1) (3 = .), gen(treatment_costs)
recode GRUPO_EXPERIMENTO_2 (1 = 0) (2 = .) (3 = 1), gen(treatment_benefits)

label def tr_d 0"Control" 1"Treatment" 
label val treatment_* tr_d

* Outcome and mediating variables
	
	* Support EU integration
gen diff_support = X2_P2 

	* Support for membership
		* Original metric
gen malo_bueno = X2_P3
recode malo_bueno (2=0) (3=1) (1=2)

label def mb 2"Bueno" 1"Ni bueno ni malo" 0"Algo malo" 
label val malo_bueno mb
		
		* Dichotomized
gen malo_bueno2 = X2_P3
recode malo_bueno2  (2=0) (3=0)

label def mb2 1"Bueno" 0"Neutral or bad"
label val malo_bueno2 mb2

	* EU policy responsiveness
gen policies = (X2_P1 * -1) + 4 

		* Dichotomized EU policy responsiveness 
recode X2_P1 (1/2 = 1) (3/4 = 0), gen(policies_di)

label def pol_di 0"No" 1"Yes" 
label val policies_di pol_di 

	* Costs of European integration
gen costs = (X2_P4 * -1) + 3

		* Dichotomized costs of European integration
recode X2_P4 (1 = 1) (2/3 = 0), gen(costs_di) 

label def cos_di 0"Ok or too low" 1"Too high" 
label val costs_di cos_di 

* Covariates 
	* Education
gen education = P11_4

	* Age 
gen age = R2 

	* Income 
gen income = P11_8 
recode income (99 = .)

	* Ideology 
gen ideology = P4_8 
gen ideology_sq = P4_8*P4_8

	* SWD
gen swd = P4_16 

	* Trust EU 
gen trust = P4_19

	* Identity
gen identi_spanish = P4_14_2 
gen identi_europ = P4_14_3

	* Satisfaction eco 
gen stfeco = P1_1

* Variable labels 
label var treatment "Treatment Group"
label var treatment_costs "Treatment costs"
label var treatment_benefits "Treatment policy benefits"
label var education "Education"
label var age "Age"
label var income "Income"
label var ideology "Ideology"
label var ideology_sq "Ideology squared"
label var trust "Trust in the EU" 
label var identi_spanish "Spanish identity"
label var identi_europ "European identity" 
label var stfeco "Satisfaction with the economy"
label var P4_2 "Political interest"


label var diff_support "Support EU integration"
label var malo_bueno "Support membership"
label var malo_bueno2 "Support membership (dichotomized)"
label var policies "Policy responsiveness"
label var policies_di  "Policy responsiveness (dichotomized)"
label var costs "Eco. costs integration" 
label var costs_d "Eco. costs integration (dichotomized)" 

************************************************
* Analysis: Article figures (3-5)
************************************************

************************************************
* Figure 3: Effects on diffuse support
************************************************

* PANEL (A): Support for EU integration
reg diff_support i.treatment
eststo support_integration

* PANEL (B): Support membership
logit malo_bueno2 i.treatment 
margins rb1.treatment, post
eststo support_membership

* Summary figure
coefplot	support_integration  || ///
			support_membership,  ///
			drop(_cons) xline(0, lpattern(solid) lcolor(red)) byopts(row(1)) levels(95)	///
			bylabels("(a) Support EU integration" "(b) Support membership") nokey	///
			rename(r2vs1.treatment = 2.treatment r3vs1.treatment = 3.treatment) ///
			coeflabel(2.treatment = "Economic costs treatment" 3.treatment = "Policy benefits treatment", wrap(20))  ///
			aspect(.75) mlabel format(%9.2g) mlabposition(12) mlabgap(*2)
			
addplot 1: , b1title("Effects treatment vs. control", size(small)) norescaling
addplot 2: , b1title("Effects treatment vs. control") norescaling

graph save ${output}Figure_3.gph, replace 
graph export ${output}Figure_3.eps, replace 

******************************************************
* Figure 4: Mediation analysis for policy benefits ad
******************************************************

* PANEL (A): Outcome: Support for European integration 
medeff	///
		(probit policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) ///
		(regress diff_support policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(policies_di) treat(treatment_benefits) ///
		sims(1250) seed(17051988) level(95)
		
		* Saving parameters into a matrix to generate a coeficient plot of the results
matrix point = J(1,3,.)
matrix CI = J(4,3,.)
matrix colnames point = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix colnames CI =  "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix rownames point = Mean
matrix rownames CI = ll95 ul95 ll90 ul90

matrix point[1,1] = `r(delta1)', `r(zeta1)', `r(tau)'
matrix CI[1,1] = `r(delta1lo)' \ `r(delta1hi)'
matrix CI[1,2] = `r(zeta1lo)' \ `r(zeta1hi)'
matrix CI[1,3] = `r(taulo)' \ `r(tauhi)' 

local ACME1 = `r(delta1)'

		* Percent of ATE that is mediated (for figure note)
local percent = `r(navg)' * 100
local percent = round(`percent', .01)

		* Saving additional parameters for appendix figure (C2)
probit policies_di treatment_benefits education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C2_Apath_coef = round(r[1,1], .01)
local C2_Apath_pval = round(r[4,1], .01)

regress diff_support policies_di treatment_benefits education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C2_Bpath_coef = round(r[1,1], .01)
local C2_Bpath_pval = round(r[4,1], .001)
local C2_Cpath_coef = round(r[1,2], .01)
local C2_Cpath_pval = round(r[4,2], .001)

* PANEL (B):  Outcome: Support for membership
medeff	///
		(probit policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) ///
		(probit malo_bueno2 policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(policies_di) treat(treatment_benefits) ///
		sims(1250) seed(17051988) level(95)

		* Saving parameters into a matrix to generate a coeficient plot of the main results of causal mediation
matrix point2 = J(1,3,.)
matrix CI2 = J(4,3,.)
matrix colnames point2 = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix colnames CI2 = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix rownames point2 = Mean
matrix rownames CI2 = ll95 ul95 ll90 ul90

local delta = (`r(delta1)' + `r(delta0)') / 2
local zeta = (`r(zeta1)' + `r(zeta0)') / 2
local deltalo = (`r(delta1lo)' + `r(delta0lo)') / 2
local deltahi = (`r(delta1hi)' + `r(delta0hi)') / 2
local zetahi = (`r(zeta1hi)' + `r(zeta0hi)') / 2
local zetalo = (`r(zeta1lo)' + `r(zeta0lo)') / 2

matrix point2[1,1] =  `delta', `zeta', `r(tau)'
matrix CI2[1,1] = `deltalo' \ `deltahi'
matrix CI2[1,2] =  `zetalo'  \ `zetahi'
matrix CI2[1,3] = `r(taulo)' \ `r(tauhi)' 

		* Percent of ATE that is mediated (for figure note)
local percent2 = ((`r(n1avg)' + `r(n0avg)') / 2)  * 100
local percent2 = round(`percent2', .01)

		* Saving additional parameters for appendix figure (C3)
probit policies_di treatment_benefits education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C3_Apath_coef = round(r[1,1], .01)
local C3_Apath_pval = round(r[4,1], .01)

probit malo_bueno2 policies_di treatment_benefits education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C3_Bpath_coef = round(r[1,1], .01)
local C3_Bpath_pval = round(r[4,1], .001)
local C3_Cpath_coef = round(r[1,2], .01)
local C3_Cpath_pval = round(r[4,2], .001)

* Summary of the matrices used to generate the plot
matrix list point2
matrix list CI2

* Summary figure
coefplot	(matrix(point), xline(0, lpattern(solid))	///
			ci((CI[1] CI[2]) (CI[3] CI[4]))) ///
			|| (matrix(point2), xline(0, lpattern(solid))	///
			ci((CI2[1] CI2[2]) (CI2[3] CI2[4]))) ///
			, nooffset nokey bylabels("(a) Support EU integration" "(b) Support membership") aspect(.75)	///
			mlabel format(%9.2g) mlabposition(12) mlabgap(*2)

addplot 1: , b1title("Percent of total effect mediated: `percent' %", size(small)) norescaling
addplot 2: , b1title("Percent of total effect mediated: `percent2' %") norescaling

graph save ${output}Figure_4.gph, replace 
graph export ${output}Figure_4.eps, replace 

******************************************************
* Figure 5: Mediation analysis for economic costs ad
******************************************************

* PANEL (A): Outcome: Support for European integration 
medeff	///
		(probit costs_di treatment_costs education age ideology ideology_sq swd identi_europ) ///
		(regress diff_support costs_di treatment_costs education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(costs_di) treat(treatment_costs) ///
		sims(1250) seed(17051988) level(95)
		
		* Saving parameters into a matrix to generate a coeficient plot of the main results of causal mediation
matrix point = J(1,3,.)
matrix CI = J(4,3,.)
matrix colnames point = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix colnames CI = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix rownames point = Mean
matrix rownames CI = ll95 ul95 ll90 ul90

matrix point[1,1] = `r(delta1)', `r(zeta1)', `r(tau)'
matrix CI[1,1] = `r(delta1lo)' \ `r(delta1hi)'
matrix CI[1,2] = `r(zeta1lo)' \ `r(zeta1hi)'
matrix CI[1,3] = `r(taulo)' \ `r(tauhi)' 

local ACME2 = `r(delta1)'

		* Percent of ATE that is mediated (for figure note)
local percent = `r(navg)' * 100
local percent = round(`percent', .01)

		* Summary of the matrices used to generate the plot
matrix list point
matrix list CI

		* Saving additional parameters for appendix figure (C4)
probit costs_di treatment_costs education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C4_Apath_coef = round(r[1,1], .01)
local C4_Apath_pval = round(r[4,1], .01)


regress diff_support costs_di treatment_costs education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C4_Bpath_coef = round(r[1,1], .01)
local C4_Bpath_pval = round(r[4,1], .001)
local C4_Cpath_coef = round(r[1,2], .01)
local C4_Cpath_pval = round(r[4,2], .001)

* PANEL (B):  Outcome: Support for membership
medeff	///
		(probit costs_di treatment_costs education age ideology ideology_sq swd identi_europ) ///
		(probit malo_bueno2 costs_di treatment_costs education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(costs_di) treat(treatment_costs) ///
		sims(1250) seed(17051988) level(95)

		* Saving parameters into a matrix to generate a coeficient plot of the main results of causal mediation
matrix point2 = J(1,3,.)
matrix CI2 = J(4,3,.)
matrix colnames point2 = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix colnames CI2 = "Mediation effect (ACME)" "Direct effect (ADE)" "Total effect (ATE)"
matrix rownames point2 = Mean
matrix rownames CI2 = ll95 ul95 ll90 ul90

local delta = (`r(delta1)' + `r(delta0)') / 2
local zeta = (`r(zeta1)' + `r(zeta0)') / 2
local deltalo = (`r(delta1lo)' + `r(delta0lo)') / 2
local deltahi = (`r(delta1hi)' + `r(delta0hi)') / 2
local zetahi = (`r(zeta1hi)' + `r(zeta0hi)') / 2
local zetalo = (`r(zeta1lo)' + `r(zeta0lo)') / 2

matrix point2[1,1] =  `delta', `zeta', `r(tau)'
matrix CI2[1,1] = `deltalo' \ `deltahi'
matrix CI2[1,2] =  `zetalo'  \ `zetahi'
matrix CI2[1,3] = `r(taulo)' \ `r(tauhi)' 

		* Percent of ATE that is mediated (for figure note)
local percent2 = ((`r(n1avg)' + `r(n0avg)') / 2)  * 100
local percent2 = round(`percent2', .01)

		* Summary of the matrices used to generate the plot
matrix list point2
matrix list CI2

		* Saving additional parameters for appendix figure (C5)
probit costs_di treatment_costs education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C5_Apath_coef = round(r[1,1], .01)
local C5_Apath_pval = round(r[4,1], .01)

probit malo_bueno2 costs_di treatment_costs education age ideology ideology_sq swd identi_europ
matrix r = r(table)
local C5_Bpath_coef = round(r[1,1], .01)
local C5_Bpath_pval = round(r[4,1], .001)
local C5_Cpath_coef = round(r[1,2], .01)
local C5_Cpath_pval = round(r[4,2], .001)

* Summary figure
coefplot	(matrix(point), xline(0, lpattern(solid))	///
			ci((CI[1] CI[2]) (CI[3] CI[4]))) ///
			|| (matrix(point2), xline(0, lpattern(solid))	///
			ci((CI2[1] CI2[2]) (CI2[3] CI2[4]))) ///
			, nooffset nokey bylabels("(a) Support EU integration" "(b) Support membership") mlabel 	///
			format(%9.2g) mlabposition(12) aspect(.75) 

addplot 1: , b1title("Percent of total effect mediated: `percent' %", size(small)) norescaling
addplot 2: , b1title("Percent of total effect mediated: `percent2' %") norescaling

graph save ${output}Figure_5.gph, replace 
graph export ${output}Figure_5.eps, replace 		

******************************************************
* Figure 6: Persistence of effects
******************************************************
preserve

* Saving variables that we need to transfer to wave 11 dataset 
keep treatment treatment_costs treatment_benefits CodPanelista

save ${working}W10_for_merging.dta, replace

* Loading wave 11 POLAT survey dataset  
use ${original}POLAT_W11.dta, clear

* Merging wave 11 dataset with treatment indicators from wave 10
merge 1:1 CodPanelista using ${working}W10_for_merging.dta

* Data management
gen diff_support = X2_P2 
gen malo_bueno2 = X2_P3
recode malo_bueno2  (2=0) (3=0)
label def mb2 1"Bueno" 0"Neutral or bad"
label val malo_bueno2 mb2

* PANEL (A): Support for EU integration
reg diff_support i.treatment
eststo support_integration

* PANEL (B): Support membership
logit malo_bueno2 i.treatment 
margins rb1.treatment, post
eststo support_membership

* Summary figure
coefplot	support_integration  || ///
			support_membership,  ///
			drop(_cons) xline(0, lpattern(solid) lcolor(red)) byopts(row(1)) levels(95)	///
			bylabels("(a) Support EU integration" "(b) Support membership") nokey	///
			rename(r2vs1.treatment = 2.treatment r3vs1.treatment = 3.treatment) ///
			coeflabel(2.treatment = "Economic costs treatment" 3.treatment = "Policy benefits treatment", wrap(20))  ///
			aspect(.75) mlabel format(%9.2g) mlabposition(12) mlabgap(*2)
			
addplot 1: , b1title("Effects treatment vs. control", size(small)) norescaling
addplot 2: , b1title("Effects treatment vs. control") norescaling

graph save ${output}Figure_6.gph, replace 
graph export ${output}Figure_6.eps, replace 


*********************************************************
* Estimating parameters for Table D1 in online appendix
*********************************************************
levelsof treatment, local(levels)
foreach x of local levels{
	sum treatment if treatment == `x'
	local `x'_2018 = `r(N)'
	sum treatment if _merge == 3 & treatment == `x'
	local `x'_2019 = `r(N)'
	local recontact = ``x'_2019' / ``x'_2018'
	matrix at_`x' = ``x'_2018', ``x'_2019', `recontact'
} 

* Storing in matrix
matrix tableD1 = at_1 \ at_3 \ at_2
matrix  colnames tableD1 = "Respondents in 2018" "Respondents in 2019" "Recontact rate"
matrix  rownames tableD1 = "Control" "Policy benefits" "Economic costs"
matrix list tableD1 

* Restoring wave 10 dataset
restore


************************************************


************************************************
* Analysis: Online appendix tables and figures
************************************************
*******************************************************************************************
* Table C1: Descriptive statistics outcome variables and mediators by treatment condition 
*******************************************************************************************
foreach var of varlist diff_support malo_bueno2 malo_bueno policies_di policies  costs_di costs {
	if `var' == diff_support{
		forval x = 1/3{
			sum `var' if treatment == `x'
			local mean = round(`r(mean)', 0.01)
			local sd = round(`r(sd)', 0.01) 
			matrix `var'`x' = `mean' , `sd'
			matrix rownames `var'`x' = `var'
			matrix descriptive`x' = `var'`x' 
		}
	}
	if `var' != diff_support{
		forval x = 1/3{
			sum `var' if treatment == `x'
			local mean = round(`r(mean)', 0.01)
			local sd = round(`r(sd)', 0.01) 
			matrix `var'`x' = `mean' , `sd'
			matrix rownames `var'`x' = `var'
			matrix descriptive`x' = descriptive`x' \ `var'`x' 
		}
	}
}

matrix colnames descriptive1 = "Control group"
matrix colnames descriptive2 = "Costs treatment"
matrix colnames descriptive3 = "Policy benefits treatment"

frmttable, statmat(descriptive1) substat(1) sdec(2) varlabels  
frmttable, statmat(descriptive2) substat(1) sdec(2) varlabels merge
frmttable using ${output}Table_C1.tex, statmat(descriptive3) substat(1) sdec(2) varlabels merge tex

*****************************
* Figure C1: Balance tests 
*****************************
gen age_10 = age / 10

label var age_10 "Age (Years/10)"

foreach tr of varlist treatment_*{
	matrix mean = J(1,9,.)
	matrix colnames mean = education age_10 income ideology P4_2 trust identi_europ identi_spanish stfeco 
	matrix CI = J(2,9,.)
	matrix colnames CI = education age_10 income ideology P4_2 trust identi_europ identi_spanish stfeco 
	matrix rownames CI = ll95 ul95
	local i 0
	foreach var of varlist education age_10 income ideology P4_2 trust identi_europ identi_spanish stfeco{
		quietly: ttest `var', by(`tr')
		local ++ i 
		local diff = r(mu_1) - r(mu_2)
		matrix mean[1, `i'] = `diff' 
		local degrees = r(df_t)
		local critical_5 = invttail(`degrees', 0.025)
		local confvalue_5 = `critical_5' * r(se)
		local ll95 = `diff' - `confvalue_5'
		local ul95 = `diff' + `confvalue_5'
		matrix CI[1, `i'] = `ll95' \ `ul95'
	}
matrix `tr'_m = mean
matrix `tr'_CI = CI
}

matrix list treatment_costs_m
matrix list treatment_costs_CI

matrix list treatment_benefits_m
matrix list treatment_benefits_CI

coefplot	(matrix(treatment_costs_m), xline(0, lpattern(solid) lcolor(red))	///
			ci((treatment_costs_CI[1] treatment_costs_CI[2]))) ///
			|| (matrix(treatment_benefits_m), xline(0, lpattern(solid) lcolor(red))	///
			ci((treatment_benefits_CI[1] treatment_benefits_CI[2]))) ///
			, byopts(row(1)) nooffset nokey ///
			bylabels("Economic costs treatment group" "Policy benefits treatment group") ///
			xlabel(-.5(.25).5) xscale(range(-.5 .5)) aspect(0.8)
			
addplot 1: , b1title("Difference between control and treatment group", size(small)) norescaling
addplot 2: , b1title("Difference between control and treatment group") norescaling

graph save ${output}Figure_C1.gph, replace
graph export ${output}Figure_C1.eps, replace

********************************************
* Figures C2-C5: Mediation models summary 
********************************************
forval x = 2/5{
	di _newline _newline "**** Figure C`x' paths ****" _newline "a path = `C`x'_Apath_coef' p-value = `C`x'_Apath_pval'" _newline "b path = `C`x'_Bpath_coef' p-value = `C`x'_Bpath_pval'" _newline "c path = `C`x'_Cpath_coef' p-value = `C`x'_Cpath_pval'"	
}

***********************************************************************
* FIGURE C6: Effects on Support for membership in its original metric
***********************************************************************
mlogit X2_P3 i.treatment
margins rb1.treatment, post coeflegend
eststo full

* Figure C6
coefplot	full, ///
			drop(_cons) xline(0, lpattern(solid) lcolor(red)) byopts(row(1)) levels(95)	///
			nokey	///
			coeflabels(r2vs1.treatment@1._predict = "A good thing"	///
			r2vs1.treatment@2._predict = "A bad thing"	///
			r2vs1.treatment@3._predict = "Neither good nor bad"	///
			r3vs1.treatment@1._predict = "A good thing"	///
			r3vs1.treatment@2._predict = "A bad thing"	///
			r3vs1.treatment@3._predict = "Neither good nor bad")	///)
			groups(r2vs1.* = "{bf:Economic costs treatment}"        ///
            r3vs1.* = "{bf:Policy benefits treatment}", angle(90))                      ///
			aspect(.85) ///
			xtitle("Support for membership")

graph save ${output}Figure_C6.gph, replace 
graph export ${output}Figure_C6.eps, replace 

************************************************************************
* Table D1: Panel attrition between 10th and 11th waves of POLAT panel
************************************************************************
frmttable, statmat(tableD1)  sdec(2) varlabels  
frmttable using ${output}tableD1.tex, statmat(tableD1) sdec(2) varlabels tex replace

******************************************************
* Appendix E: Sensitiviy analyses of causal mediation
*******************************************************

set seed 17051988

***********************************************************************************************
* Figure E1: ACME as a function of degree of violation of sequential ignorability assumption
***********************************************************************************************

* PANEL A: For policy benefits ad mediation on support for EU integration
medsens	///
		(probit policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) ///
		(regress diff_support policies_di treatment_benefits education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(policies_di) treat(treatment_benefits) ///
		sims(1250) level(95)	
		
twoway	rarea _med_updelta0 _med_lodelta0 _med_rho, bcolor(gs14) || line ///
		_med_delta0 _med_rho, lcolor(black) ytitle("ACME") title("(A) ACME({&rho}) policy benefits ad") ///
		xtitle("Sensitivity parameter: {&rho}") legend(off)
		
graph save ${aux}sensitivity_policybenefits_integration.gph, replace
	
* PANEL B: For costs ad mediation on support for membership
medsens	///
		(probit costs_di treatment_costs education age ideology ideology_sq swd identi_europ) ///
		(regress diff_support costs_di treatment_costs education age ideology ideology_sq swd identi_europ) /// 
		,  mediate(costs_di) treat(treatment_costs) ///
		sims(1250) level(95)  
		
local parameter =  `r(r2s_thresh)'
di `parameter'
		
twoway	rarea _med_updelta0 _med_lodelta0 _med_rho, bcolor(gs14) || line ///
		_med_delta0 _med_rho, lcolor(black) ytitle("ACME") title("(B) ACME({&rho}) economic costs ad") ///
		xtitle("Sensitivity parameter: {&rho}") legend(off)
	
graph save ${aux}sensitivity_costs_supportintegration.gph, replace

graph combine	"${aux}sensitivity_policybenefits_integration.gph"	///
				"${aux}sensitivity_costs_supportintegration.gph", ycommon
				
graph save ${output}Figure_E1.gph, replace
graph export ${output}Figure_E1.eps, replace

*******************************************************************************************************************
* Figure E2: Residual variance of outcome and mediator that must be jointly explained by counfounder for ACME = 0
*******************************************************************************************************************
* Creating R2 plot based on the value of R^2_M*R^2_Y* at which ACME = 0 
matrix sensi = J(142,2,.)
matrix colnames sensi = "x" "y"
local i 0
forval x = .2(.01).91{
	local ++ i
	local y = `parameter' / `x'
	matrix sensi[`i',1] = `x' , `y'
}
local i 71
forval y = .2(.01).91{
	local ++ i
	local x = `parameter' / `y'
	matrix sensi[`i',1] = `x' , `y'
}
svmat sensi, names(col)

sort x

graph twoway	(line y x,	///
				xtitle("R{superscript:2*}{subscript:M}")	///
				ytitle("R{superscript:2*}{subscript:Y}") aspect(1)) 
				
graph save ${output}Figure_E2.gph, replace
graph export ${output}Figure_E2.eps, replace

log close


